@@ -1,6 +1,9 @@
 SampleMat2 <-
 function(ref, ratio, as.logi=FALSE)
 {
+    # set a new random seed to ensure that sampling is random (issue when CTA is involved and seed needs to be set to a fix number)
+    set.seed(as.double(Sys.time()) + as.numeric(format(Sys.time(), "%OS6"))*1000000)
+    
     ntot <- length(ref)
     npres<- sum(ref)    
     ncal <- ceiling(ntot*ratio)
