@@ -122,7 +122,7 @@ setMethod('.transform.outputs', signature(modOut='list'),
                     'models.run', 'EF.prediction', 'EF.PCA.median', 'EF.evaluation' ) )){
       stop(paste("out argument must be one of ", toString(c('evaluation', 'prediction', 'prediction.eval', 'var.import',
                                                             'calib.failure', 'models.run', 'EF.prediction',
-                                                            'EF.PCA.median', 'EF.evaluation',  ))))
+                                                            'EF.PCA.median', 'EF.evaluation'))))
     }
     
     if(length(modOut) == 1 & length(unlist(strsplit(unlist(names(modOut)),'_'))) == 1 ){
@@ -466,7 +466,7 @@ DF_to_ARRAY <- function(df){
   
   a <- sapply(strsplit(colnames(df), '_'), tail, n=3)
   b <- lapply(1:3, function(id) return(unique(a[id,])))
-  array.dim.names <- c(list(c(NULL)),rev(b))
+  array.dim.names <- c(list(character(0)),rev(b))
 #   array.dim.names <- c(list(c(NULL)),rev(apply(sapply(strsplit(colnames(df), '_'), tail, n=3),1,unique)))
   
   array.dim <- c(nrow(df),sapply(array.dim.names[-1],length))
